@@ -22,7 +22,7 @@
  * @author Michał Bąbik <michalb1981@o2.pl>
  */
 #include <glib.h>
-#include <stdint.h>
+#include <inttypes.h>
 #include <stdio.h>
 #include "defs.h"
 #include "strfn.h"
@@ -33,19 +33,20 @@
  */
 size_t
 get_valid_length (const char   *s_str,
-                  const size_t  ul_max)
+                  const size_t  ui_max)
 {
-    size_t ul_len = 0;
+    const char *s_end  = NULL;
+    size_t      ui_len = 0;
 
-    ul_len = strlen (s_str);
+    ui_len = strlen (s_str);
 
-    if (ul_len > ul_max)
-        ul_len = ul_max;
+    if (ui_len > ui_max)
+        ui_len = ui_max;
 
-    while (!g_utf8_validate (s_str, (long int) ul_len, NULL))
-        ul_len--;
+    g_utf8_validate (s_str, (gssize) ui_len, &s_end);
+    ui_len = (size_t) (s_end - s_str);
 
-    return ul_len;
+    return ui_len;
 }
 /*----------------------------------------------------------------------------*/
 /** 
@@ -56,16 +57,14 @@ string_replace_in (char              *s_src_dst,
                    const ProcessData *pd_data)
 {
     char          s_tmp [FN_LEN+1];           /* temp file name */
-    size_t        ul_vlen  = 0;               /* valid name length */
-    uint16_t      i        = 0;
-    size_t        ul_frlen = 0;               /* rename from length */
-    const size_t  ul_max   = FN_LEN;          /* max length of name */
+    size_t        ui_vlen  = 0;               /* valid name length */
+    size_t        i        = 0;
+    size_t        ui_frlen = 0;               /* rename from length */
+    const size_t  ui_max   = FN_LEN;          /* max length of name */
     const char   *s_fr     = pd_data->s_str1; /* "replace from" string */
     const char   *s_to     = pd_data->s_str2; /* "replace to" string */
     char         *fp       = NULL;            /* find string pointer */
 
-    memset (s_tmp, '\0', sizeof (s_tmp));
-
     if (g_utf8_validate (s_src_dst, -1, NULL) && 
         g_utf8_validate (s_fr, -1, NULL) &&
         g_utf8_validate (s_to, -1, NULL) ) {
@@ -78,7 +77,7 @@ string_replace_in (char              *s_src_dst,
         if (fp == NULL)
             return; 
 
-        ul_frlen = strlen (s_fr);
+        ui_frlen = strlen (s_fr);
 
         while (fp != NULL) {
 
@@ -93,20 +92,21 @@ string_replace_in (char              *s_src_dst,
             }
 
             /* change source pointer to "after found" */
-            sp = fp + ul_frlen; 
+            sp = fp + ui_frlen; 
             fp = strstr (sp, s_fr);
         }
         while (*sp && i < FN_LEN) {
             dp[i++] = *sp++;
         }
+        dp[i] = '\0';
     }
     else
         return;
 
-    ul_vlen = get_valid_length (s_tmp, ul_max);
+    ui_vlen = get_valid_length (s_tmp, ui_max);
 
-    memcpy (s_src_dst, s_tmp, ul_vlen);
-    s_src_dst[ul_vlen] = '\0';
+    memcpy (s_src_dst, s_tmp, ui_vlen);
+    s_src_dst[ui_vlen] = '\0';
 
     #ifdef DEBUG
         printf ("\n%ld %s\n", strlen (s_tmp), s_tmp);
@@ -121,38 +121,38 @@ void
 string_delete_chars (char              *s_src_dst,
                      const ProcessData *pd_data)
 {
-    size_t  ul_cnt  = pd_data->ul_cnt;    /* Delete chars count */
-    size_t  ul_pos  = pd_data->ul_pos;    /* Delete start position */
-    size_t  ul_len  = 0;    /* Length of text to process */
-    size_t  ul_olen = 0;    /* Length of text before processing */
+    size_t  ui_cnt  = pd_data->ui_cnt;    /* Delete chars count */
+    size_t  ui_pos  = pd_data->ui_pos;    /* Delete start position */
+    size_t  ui_len  = 0;    /* Length of text to process */
+    size_t  ui_olen = 0;    /* Length of text before processing */
     char   *ch_po   = NULL; /* Pointer to delete start position */
     char   *ch_cn   = NULL; /* Pointer to position after deleted chars */
 
-    if (ul_cnt == 0)
+    if (ui_cnt == 0)
         return;
 
     if (g_utf8_validate (s_src_dst, -1, NULL)) {
 
-        ul_len = strlen (s_src_dst);
+        ui_len = strlen (s_src_dst);
 
-        ul_olen = ul_len;
-        ul_len = (size_t) g_utf8_strlen (s_src_dst, -1);
+        ui_olen = ui_len;
+        ui_len = (size_t) g_utf8_strlen (s_src_dst, -1);
 
-        if (ul_cnt > ul_len)
-            ul_cnt = ul_len;
-        if (ul_pos > ul_len)
-            ul_pos = ul_len;
+        if (ui_cnt > ui_len)
+            ui_cnt = ui_len;
+        if (ui_pos > ui_len)
+            ui_pos = ui_len;
 
-        if (ul_pos + ul_cnt > ul_len) {
-            if (ul_pos == ul_len)
-                ul_pos = ul_len - ul_cnt;
+        if (ui_pos + ui_cnt > ui_len) {
+            if (ui_pos == ui_len)
+                ui_pos = ui_len - ui_cnt;
             else
-                ul_cnt = ul_len - ul_pos;
+                ui_cnt = ui_len - ui_pos;
         }
-        ch_po = g_utf8_offset_to_pointer (s_src_dst, (glong) ul_pos);
-        ch_cn = g_utf8_offset_to_pointer (s_src_dst, (glong) (ul_pos + ul_cnt));
+        ch_po = g_utf8_offset_to_pointer (s_src_dst, (glong) ui_pos);
+        ch_cn = g_utf8_offset_to_pointer (s_src_dst, (glong) (ui_pos + ui_cnt));
 
-        memmove (ch_po, ch_cn, ul_olen - ul_pos - (size_t) (ch_cn - ch_po) + 1);
+        memmove (ch_po, ch_cn, ui_olen - ui_pos - (size_t) (ch_cn - ch_po) + 1);
     }
 }
 /*----------------------------------------------------------------------------*/
@@ -164,16 +164,14 @@ string_insert_string (char              *s_src_dst,
                       const ProcessData *pd_data)
 {
     char          s_tmp [FN_LEN+1];             /* Temp String */
-    size_t        ul_pos     = pd_data->ul_pos; /* Text insert position  */
-    size_t        ul_len     = 0;               /* Length of text */
-    size_t        ul_slen_u8 = 0;               /* Length of unicode text */
+    size_t        ui_pos     = pd_data->ui_pos; /* Text insert position  */
+    size_t        ui_len     = 0;               /* Length of text */
+    size_t        ui_slen_u8 = 0;               /* Length of unicode text */
     size_t        i          = 0;
-    const size_t  ul_max     = FN_LEN;          /* Max string length */
+    const size_t  ui_max     = FN_LEN;          /* Max string length */
     const char   *s_ins      = pd_data->s_str1; /* Text to insert */
     const char   *x          = NULL;            /* Insert text pointer */
 
-    memset (s_tmp, '\0', sizeof (s_tmp));
-
     if (g_utf8_validate (s_src_dst, -1, NULL) && 
         g_utf8_validate (s_ins, -1, NULL)) {
 
@@ -181,32 +179,33 @@ string_insert_string (char              *s_src_dst,
         const char * __restrict sp = s_src_dst; /* Source string pointer */
         const char * __restrict ip = s_ins;     /* Insert string pointer */
 
-        ul_slen_u8 = (size_t) g_utf8_strlen (sp, -1);
+        ui_slen_u8 = (size_t) g_utf8_strlen (sp, -1);
 
-        if (ul_pos > ul_slen_u8)
-            ul_pos = ul_slen_u8;
+        if (ui_pos > ui_slen_u8)
+            ui_pos = ui_slen_u8;
 
-        x = g_utf8_offset_to_pointer (sp, (glong) ul_pos);
+        x = g_utf8_offset_to_pointer (sp, (glong) ui_pos);
 
         while (sp != x) {
             tp[i++] = *sp++;
         }
 
-        while (*ip && i < ul_max) {
+        while (*ip && i < ui_max) {
             tp[i++] = *ip++;
         }
 
-        while (*sp && i < ul_max) {
+        while (*sp && i < ui_max) {
             tp[i++] = *sp++;
         }
+        tp[i] = '\0';
     }
     else
         return;
 
-    ul_len = get_valid_length (s_tmp, ul_max);
+    ui_len = get_valid_length (s_tmp, ui_max);
 
-    memcpy (s_src_dst, s_tmp, ul_len);
-    s_src_dst[ul_len] = '\0';
+    memcpy (s_src_dst, s_tmp, ui_len);
+    s_src_dst[ui_len] = '\0';
 
     #ifdef DEBUG
         printf ("\n%ld %s\n", strlen (s_tmp), s_tmp);
@@ -222,17 +221,15 @@ string_overwrite_string (char              *s_src_dst,
                          const ProcessData *pd_data)
 {
     char          s_tmp [FN_LEN+1];             /* Temp String */
-    size_t        ul_pos     = pd_data->ul_pos; /* Text insert position  */
-    size_t        ul_len     = 0;               /* Length of text */
-    long          l_ilen     = 0;               /* Length of overwrite text */
-    size_t        ul_slen_u8 = 0;               /* Length of unicode text */
+    size_t        ui_pos     = pd_data->ui_pos; /* Text insert position  */
+    size_t        ui_len     = 0;               /* Length of text */
+    size_t        ui_ilen    = 0;               /* Length of overwrite text */
+    size_t        ui_slen_u8 = 0;               /* Length of unicode text */
     size_t        i          = 0;
-    const size_t  ul_max     = FN_LEN;          /* Max string length */
+    const size_t  ui_max     = FN_LEN;          /* Max string length */
     const char   *s_ins      = pd_data->s_str1; /* Overwrite text */
     const char   *x          = NULL;            /* Overwrite start pointer */
 
-    memset (s_tmp, '\0', sizeof (s_tmp));
-
     if (g_utf8_validate (s_src_dst, -1, NULL) && 
         g_utf8_validate (s_ins, -1, NULL)) {
 
@@ -240,42 +237,43 @@ string_overwrite_string (char              *s_src_dst,
         const char * __restrict sp = s_src_dst; /* Source string pointer */
         const char * __restrict ip = s_ins;     /* Insert string pointer */
 
-        ul_slen_u8 = (size_t) g_utf8_strlen (sp, -1);
-        l_ilen     = g_utf8_strlen (ip, -1);
+        ui_slen_u8 = (size_t) g_utf8_strlen (sp, -1);
+        ui_ilen    = (size_t) g_utf8_strlen (ip, -1);
 
-        if (ul_pos + (size_t) l_ilen > ul_slen_u8) {
-            if (l_ilen > (long) ul_slen_u8)
-                ul_pos = 0;
+        if (ui_pos + (size_t) ui_ilen > ui_slen_u8) {
+            if (ui_ilen > ui_slen_u8)
+                ui_pos = 0;
             else
-                ul_pos = ul_slen_u8 - (size_t) l_ilen;
+                ui_pos = ui_slen_u8 - (size_t) ui_ilen;
         }
 
-        x = g_utf8_offset_to_pointer (sp, (glong) ul_pos);
+        x = g_utf8_offset_to_pointer (sp, (glong) ui_pos);
 
         while (sp != x) {
             tp[i++] = *sp++;
         }
 
-        while (*ip && i < ul_max) {
+        while (*ip && i < ui_max) {
             tp[i++] = *ip++;
         }
 
-        if (g_utf8_strlen (sp, -1) > l_ilen) {
+        if ((size_t) g_utf8_strlen (sp, -1) > ui_ilen) {
 
-            sp = g_utf8_offset_to_pointer (sp, l_ilen);
+            sp = g_utf8_offset_to_pointer (sp, (glong) ui_ilen);
 
-            while (*sp && i < ul_max) {
+            while (*sp && i < ui_max) {
                 tp[i++] = *sp++;
             }
         }
+        tp[i] = '\0';
     }
     else
         return;
     
-    ul_len = get_valid_length (s_tmp, ul_max);
+    ui_len = get_valid_length (s_tmp, ui_max);
 
-    memcpy (s_src_dst, s_tmp, ul_len);
-    s_src_dst[ul_len] = '\0';
+    memcpy (s_src_dst, s_tmp, ui_len);
+    s_src_dst[ui_len] = '\0';
 
     #ifdef DEBUG
         printf ("\n%ld %s\n", strlen (s_tmp), s_tmp);
@@ -290,13 +288,13 @@ void
 string_add_number (char              *s_src_dst,
                    const ProcessData *pd_data)
 {
-    char         s_no  [20];                  /* Temp string for number */
-    char         s_tmp [20];                  /* Temp string */
-    unsigned int ui_no    = pd_data->i_no;    /* Number to insert */
-    unsigned int ui_st    = pd_data->i_start; /* Start numbering position */
-    unsigned int ui_mx    = pd_data->i_max;   /* Max number range */
-    unsigned int ui_z     = 0;                /* How many zeros to add */
-    unsigned int ui_t     = 0;                /* Temp value */
+    char          s_no  [20];                  /* Temp string for number */
+    char          s_tmp [20];                  /* Temp string */
+    uint_fast32_t ui_no    = pd_data->i_no;    /* Number to insert */
+    uint_fast32_t ui_st    = pd_data->i_start; /* Start numbering position */
+    uint_fast32_t ui_mx    = pd_data->i_max;   /* Max number range */
+    uint_fast32_t ui_z     = 0;                /* How many zeros to add */
+    uint_fast32_t ui_t     = 0;                /* Temp value */
     ProcessData  pd_data2 = { NULL, NULL, 0, 0, 0, 0, 0 };
 
     memset (s_no,  '\0', sizeof (s_no));
@@ -318,15 +316,15 @@ string_add_number (char              *s_src_dst,
         ui_z--;
     }
 
-    for (unsigned int i = 0; i < ui_z; ++i) {
+    for (uint_fast32_t i = 0; i < ui_z; ++i) {
         s_no[i] = '0';
     }
 
-    sprintf (s_tmp, "%d", ui_no);
+    sprintf (s_tmp, "%" PRIdFAST32, ui_no);
     strcat (s_no, s_tmp);
 
     pd_data2.s_str1 = s_no;
-    pd_data2.ul_pos = pd_data->ul_pos;
+    pd_data2.ui_pos = pd_data->ui_pos;
 
     string_insert_string (s_src_dst, &pd_data2);
 
@@ -343,19 +341,18 @@ string_to_lower (char              *s_src_dst,
                  const ProcessData *pd_data __attribute__ ((unused)))
 {
     char         *s_tt   = NULL;   /* temp string */
-    const size_t  ul_max = FN_LEN; /* Max string length */
-    size_t        ul_len = 0;      /* Length of name string */
+    const size_t  ui_max = FN_LEN; /* Max string length */
+    size_t        ui_len = 0;      /* Length of name string */
 
     if (g_utf8_validate (s_src_dst, -1, NULL)) {
 
-        s_tt = g_utf8_strdown (s_src_dst, -1);
-
-        ul_len = get_valid_length (s_tt, ul_max);
-
-        memcpy (s_src_dst, s_tt, ul_len);
+        s_tt   = g_utf8_strdown (s_src_dst, -1);
+        ui_len = get_valid_length (s_tt, ui_max);
+        memcpy (s_src_dst, s_tt, ui_len);
+        s_src_dst[ui_len] = '\0';
 
         #ifdef DEBUG
-            printf ("\n%ld %s\n", ul_len, s_tt);
+            printf ("\n%ld %s\n", ui_len, s_tt);
             printf ("%ld %s\n", strlen (s_src_dst), s_src_dst);
         #endif
 
@@ -371,19 +368,18 @@ string_to_upper (char              *s_src_dst,
                  const ProcessData *pd_data __attribute__ ((unused)))
 {
     char         *s_tt   = NULL;   /* temp string */
-    const size_t  ul_max = FN_LEN; /* Max string length */
-    size_t        ul_len = 0;      /* Length of name string */
+    const size_t  ui_max = FN_LEN; /* Max string length */
+    size_t        ui_len = 0;      /* Length of name string */
 
     if (g_utf8_validate (s_src_dst, -1, NULL)) {
 
-        s_tt = g_utf8_strup(s_src_dst, -1);
-
-        ul_len = get_valid_length (s_tt, ul_max);
-
-        memcpy (s_src_dst, s_tt, ul_len);
+        s_tt   = g_utf8_strup(s_src_dst, -1);
+        ui_len = get_valid_length (s_tt, ui_max);
+        memcpy (s_src_dst, s_tt, ui_len);
+        s_src_dst[ui_len] = '\0';
 
         #ifdef DEBUG
-            printf ("\n%ld %s\n", ul_len, s_tt);
+            printf ("\n%ld %s\n", ui_len, s_tt);
             printf ("%ld %s\n", strlen (s_src_dst), s_src_dst);
         #endif
 
@@ -406,10 +402,12 @@ string_extract_name_ext (const char *s_name_ext,
         strcpy (s_name, s_name_ext); 
     }
     else { /* should be file name with ext */
+        size_t ui_len = (size_t) (pn - s_name_ext);
         /* copy extension to f_ext */
         strcpy (s_ext, pn); 
         /* copy name to f_name */
-        memcpy (s_name, s_name_ext, (size_t) (pn - s_name_ext)); 
+        memcpy (s_name, s_name_ext, ui_len); 
+        s_name[ui_len] = '\0';
     }
 }
 /*----------------------------------------------------------------------------*/
@@ -421,21 +419,21 @@ string_combine_name_ext (char       *s_name_ext,
                          const char *s_name,
                          const char *s_ext)
 {
-    size_t       ul_len  = 0;
-    const size_t ul_elen = strlen (s_ext);
-    const size_t ul_max  = FN_LEN - ul_elen;
+    size_t       ui_len  = 0;
+    const size_t ui_elen = strlen (s_ext);
+    const size_t ui_max  = FN_LEN - ui_elen;
 
-    memset (s_name_ext, '\0', FN_LEN + 1);
-
-    ul_len = get_valid_length (s_name, ul_max);
+    ui_len = get_valid_length (s_name, ui_max);
 
     if (strcmp (s_ext, "") != 0) { /* extension present */
 
-        memcpy (s_name_ext, s_name, ul_len);
-        memcpy (s_name_ext + ul_len, s_ext, ul_elen);
+        memcpy (s_name_ext, s_name, ui_len);
+        memcpy (s_name_ext + ui_len, s_ext, ui_elen);
+        s_name_ext[ui_len + ui_elen] = '\0';
     }
     else { /* no extenstion */
-        memcpy (s_name_ext, s_name, ul_len);
+        memcpy (s_name_ext, s_name, ui_len);
+        s_name_ext[ui_len] = '\0';
     }
     #ifdef DEBUG
         printf ("f %s e %s \n", s_name, s_ext);
@@ -446,21 +444,21 @@ string_combine_name_ext (char       *s_name_ext,
  * @brief  Function to process file name str using a pointed function.
  */
 void
-string_process_filename (void          (*fun) (char*, const ProcessData*),
-                         char           *s_src_dst,
-                         ProcessData    *pd_data,
-                         const int       ne)
+string_process_filename (void             (*fun) (char*, const ProcessData*),
+                         char              *s_src_dst,
+                         const ProcessData *pd_data,
+                         const int8_t       ne)
 {
     char f_name [FN_LEN + 1]; /* temp name */
     char f_ext  [FN_LEN + 1]; /* temp extension */
 
+    f_name [0] = '\0';
+    f_ext  [0] = '\0';
+
     if (ne == 2)
         fun (s_src_dst, pd_data); /* change text in name and ext */
     else { /* change text in name or ext */
 
-        memset (f_name, '\0', sizeof (f_name));
-        memset (f_ext,  '\0', sizeof (f_ext));
-
         /* get name and ext to separate strings */
         string_extract_name_ext (s_src_dst, f_name, f_ext);
 
